@@ -1,4 +1,4 @@
-/* Copyright 2017,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2017,2018,2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,7 +41,7 @@
 /**   DATES      : # Version 6.0  : from : 26 jan 2017     **/
 /**                                 to   : 22 may 2018     **/
 /**                # Version 7.0  : from : 17 jan 2020     **/
-/**                                 to   : 17 jan 2020     **/
+/**                                 to   : 04 jul 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -56,6 +56,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "../libscotch/module.h"
+#include "../libscotch/common.h"
+
 #include "scotch.h"
 
 /*********************/
