@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2010,2011,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2008,2010,2011,2014,2018,2019,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,6 +47,8 @@
 /**                                 to   : 14 apr 2011     **/
 /**                # Version 6.0  : from : 11 sep 2011     **/
 /**                                 to   : 15 may 2018     **/
+/**                # Version 7.0  : from : 27 aug 2019     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /**   NOTES      : # Since only edges from local vertices  **/
 /**                  to local anchors are created in       **/
@@ -64,8 +66,6 @@
 **  The defines and includes.
 */
 
-#define BDGRAPH_BIPART_BD
-
 #include "module.h"
 #include "common.h"
 #include "parser.h"
@@ -131,7 +131,7 @@ const BdgraphBipartBdParam * const  paraptr)      /*+ Method parameters +*/
   if (dgraphBand (&orggrafptr->s, orggrafptr->fronlocnbr, orggrafptr->fronloctab, orggrafptr->partgsttax,
                   orggrafptr->complocload0, orggrafptr->s.velolocsum - orggrafptr->complocload0, paraptr->distmax,
                   &bndgrafdat.s, &bndgrafdat.fronloctab, &bndgrafdat.partgsttax,
-                  &bndvertlvlnum, &bndvertlocnbr1, &bndvertlocancadj) != 0) {
+                  &bndvertlvlnum, &bndvertlocnbr1, &bndvertlocancadj, orggrafptr->contptr) != 0) {
     errorPrint ("bdgraphBipartBd: cannot create band graph");
     return     (1);
   }
@@ -204,6 +204,7 @@ const BdgraphBipartBdParam * const  paraptr)      /*+ Method parameters +*/
   bndgrafdat.domnwght[0]      = orggrafptr->domnwght[0];
   bndgrafdat.domnwght[1]      = orggrafptr->domnwght[1];
   bndgrafdat.levlnum          = orggrafptr->levlnum;
+  bndgrafdat.contptr          = orggrafptr->contptr;
 
   if (bndgrafdat.veexloctax != NULL) {
     Gnum                bndveexglbanc0;
