@@ -1,4 +1,4 @@
-/* Copyright 2010,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2010,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,7 +42,7 @@
 /**   DATES      : # Version 5.1  : from : 23 jul 2010     **/
 /**                                 to   : 23 jul 2010     **/
 /**                # Version 7.0  : from : 19 jan 2023     **/
-/**                                 to   : 19 jan 2023     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -67,14 +67,14 @@ char * const                bsrcptr,
 char * const                bdstptr,
 const char * const          pattstr,
 const char * const          replstr,
-const int                   pattsiz,
-const int                   replsiz)
+const size_t                pattsiz,
+const size_t                replsiz)
 {
   char *              pattptr;
-  int                 pattidx;
+  size_t              pattidx;
 
-  pattptr = strstr (bsrcptr, pattstr);            /* Search for the pattern in the remaining source string   */
-  pattidx = (pattptr == NULL) ? (strlen (bsrcptr) + 1): (pattptr - bsrcptr); /* Get length of unchanged part */
+  pattptr = strstr (bsrcptr, pattstr);            /* Search for the pattern in the remaining source string             */
+  pattidx = (pattptr == NULL) ? (strlen (bsrcptr) + 1) : (size_t) (pattptr - bsrcptr); /* Get length of unchanged part */
 
   if (replsiz < pattsiz)                          /* If replacement is smaller, pre-move unchanged part */
     memMov (bdstptr, bsrcptr, pattidx * sizeof (char));
@@ -87,8 +87,6 @@ const int                   replsiz)
 
   if (pattptr != NULL)                            /* If there is something to replace         */
     memCpy (bdstptr + pattidx, replstr, replsiz * sizeof (char)); /* Write replacement string */
-
-  return;
 }
 
 void
@@ -97,8 +95,8 @@ char * const                buffptr,              /* String to search into */
 const char * const          pattstr,              /* Pattern to search for */
 const char * const          replstr)              /* Replacement string    */
 {
-  int                 pattsiz;
-  int                 replsiz;
+  size_t              pattsiz;
+  size_t              replsiz;
 
   pattsiz = strlen (pattstr);
   replsiz = strlen (replstr);
