@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2010,2012,2014,2018,2019,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2010,2012,2014,2018,2019,2021,2023-2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -56,7 +56,7 @@
 /**                # Version 6.1  : from : 09 feb 2021     **/
 /**                                 to   : 22 jun 2021     **/
 /**                # Version 7.0  : from : 25 aug 2019     **/
-/**                                 to   : 02 dec 2024     **/
+/**                                 to   : 13 aug 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -103,6 +103,7 @@
 #include "dgraph.h"
 #include "dgraph_halo.h"
 #include "dmapping.h"
+#include "dmesh.h"
 #include "dorder.h"
 #include "library_dmapping.h"
 #endif /* SCOTCH_PTSCOTCH */
@@ -267,23 +268,25 @@ char *                      argv[])
   subsFill ("DUMMYSIZEDGRAPHHALOREQ", subsSize (sizeof (DgraphHaloRequest))); /* TRICK: before DUMMYSIZEDGRAPH */
   subsFill ("DUMMYSIZEDGRAPH", subsSize (sizeof (Dgraph)));
   subsFill ("DUMMYSIZEDMAP", subsSize (sizeof (LibDmapping)));
+  subsFill ("DUMMYSIZEDMESH", subsSize (sizeof (Dmesh)));
   subsFill ("DUMMYSIZEDORDER", subsSize (sizeof (Dorder)));
 #else /* SCOTCH_PTSCOTCH */
   subsFill ("DUMMYSIZEDGRAPHHALOREQ", "1");       /* TRICK: before DUMMYSIZEDGRAPH */
   subsFill ("DUMMYSIZEDGRAPH", "1");
   subsFill ("DUMMYSIZEDMAP", "1");
+  subsFill ("DUMMYSIZEDMESH", "1");
   subsFill ("DUMMYSIZEDORDER", "1");
 #endif /* SCOTCH_PTSCOTCH */
   subsFill ("##SCOTCH_NAME_SUFFIX", suffptr);
   if (suffptr[0] != '\0') {                       /* If suffix provided */
 #ifdef SCOTCH_RENAME_ALL
-    subsSuffix ("SCOTCH_VERSION");
-    subsSuffix ("SCOTCH_RELEASE");
-    subsSuffix ("SCOTCH_PATCHLEVEL");
     subsSuffix ("SCOTCH_COARSENNONE");
     subsSuffix ("SCOTCH_COARSENFOLD");
     subsSuffix ("SCOTCH_COARSENFOLDDUP");
     subsSuffix ("SCOTCH_COARSENNOMERGE");
+    subsSuffix ("SCOTCH_OPTIONNUMDETERMINISTIC");
+    subsSuffix ("SCOTCH_OPTIONNUMRANDOMFIXEDSEED");
+    subsSuffix ("SCOTCH_OPTIONNUMNBR");
     subsSuffix ("SCOTCH_STRATDEFAULT");
     subsSuffix ("SCOTCH_STRATQUALITY");
     subsSuffix ("SCOTCH_STRATSPEED");
@@ -296,16 +299,53 @@ char *                      argv[])
     subsSuffix ("SCOTCH_STRATLEVELMIN");
     subsSuffix ("SCOTCH_STRATLEAFSIMPLE");
     subsSuffix ("SCOTCH_STRATSEPASIMPLE");
-#endif /* SCOTCH_RENAME_ALL */
+    subsSuffix ("SCOTCH_STRATDISCONNECTED");
 #ifdef SCOTCH_PTSCOTCH
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DGRID");
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DTORUS");
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DNGB6");
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DNGB26");
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DVERTLOAD");
+    subsSuffix ("SCOTCH_DGRAPHBUILDGRID3DEDGELOAD");
+#else /* SCOTCH_PTSCOTCH */
+#endif /* SCOTCH_PTSCOTCH */
+#endif /* SCOTCH_RENAME_ALL */
+    subsSuffix ("SCOTCH_VERSION");
+    subsSuffix ("SCOTCH_RELEASE");
+    subsSuffix ("SCOTCH_PATCHLEVEL");
+    subsSuffix ("SCOTCH_IDXSIZE");                /* Centralized Fortran types also needed in "ptscotchf.h" */
+    subsSuffix ("SCOTCH_NUMSIZE");
+    subsSuffix ("SCOTCH_ARCHDIM");
+    subsSuffix ("SCOTCH_ARCHDOMDIM");
+    subsSuffix ("SCOTCH_CONTEXTDIM");
+    subsSuffix ("SCOTCH_GEOMDIM");
+    subsSuffix ("SCOTCH_GRAPHDIM");
+    subsSuffix ("SCOTCH_MAPDIM");
+    subsSuffix ("SCOTCH_MESHDIM");
+    subsSuffix ("SCOTCH_ORDERDIM");
+    subsSuffix ("SCOTCH_STRATDIM");
+#ifdef SCOTCH_PTSCOTCH
+    subsSuffix ("SCOTCH_NUM_MPI");
+    subsSuffix ("SCOTCH_Dgraph");
+    subsSuffix ("SCOTCH_DgraphHaloReq");
+    subsSuffix ("SCOTCH_Dmapping");
+    subsSuffix ("SCOTCH_Dmesh");
+    subsSuffix ("SCOTCH_Dordering");
+    subsSuffix ("SCOTCH_DGRAPHDIM");
+    subsSuffix ("SCOTCH_DGRAPHHALOREQDIM");
+    subsSuffix ("SCOTCH_DMAPDIM");
+    subsSuffix ("SCOTCH_DORDERDIM");
 #else /* SCOTCH_PTSCOTCH */
     subsSuffix ("SCOTCH_Idx");
     subsSuffix ("SCOTCH_Num");
     subsSuffix ("SCOTCH_NUMMAX");
     subsSuffix ("SCOTCH_NUMSTRING");
     subsSuffix ("SCOTCH_Arch");
+    subsSuffix ("SCOTCH_ArchDom");
+    subsSuffix ("SCOTCH_Context");
     subsSuffix ("SCOTCH_Geom");
     subsSuffix ("SCOTCH_Graph");
+    subsSuffix ("SCOTCH_GraphPart2");
     subsSuffix ("SCOTCH_Mesh");
     subsSuffix ("SCOTCH_Mapping");
     subsSuffix ("SCOTCH_Ordering");
