@@ -1,4 +1,4 @@
-/* Copyright 2010,2011,2012,2014,2015,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2010,2011,2012,2014,2015,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,7 +45,7 @@
 /**                # Version 6.0  : from : 03 mar 2011     **/
 /**                                 to   : 25 feb 2018     **/
 /**                # Version 7.0  : from : 03 aug 2018     **/
-/**                                 to   : 20 jan 2023     **/
+/**                                 to   : 19 jul 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -105,9 +105,9 @@ const KgraphMapMlParam * const        paraptr)    /*+ Method parameters
                     finegrafptr->r.m.parttax, finepfixtax, finegrafptr->vfixnbr, finegrafptr->contptr) != 0)
     return (1);
 
-  mapInit2 (&coargrafptr->m,   &coargrafptr->s, finegrafptr->m.archptr,   &finegrafptr->m.domnorg,   finegrafptr->m.domnmax,   finegrafptr->m.domnnbr);
-  mapInit2 (&coargrafptr->r.m, &coargrafptr->s, finegrafptr->r.m.archptr, &finegrafptr->r.m.domnorg, finegrafptr->r.m.domnmax, finegrafptr->r.m.domnnbr);
-  coargrafptr->m.domntab = finegrafptr->m.domntab; /* Get domain private array, if any */
+  coargrafptr->domnorg = finegrafptr->domnorg;    /* Keep initial domain */
+  mapInit2 (&coargrafptr->m,   &coargrafptr->s, finegrafptr->m.archptr,   finegrafptr->m.domnmax,   finegrafptr->m.domnnbr);
+  mapInit2 (&coargrafptr->r.m, &coargrafptr->s, finegrafptr->r.m.archptr, finegrafptr->r.m.domnmax, finegrafptr->r.m.domnnbr);
 
   coargrafptr->comploadavg = finegrafptr->comploadavg; /* By default, use fine target load arrays as coarse load arrays */
   coargrafptr->comploaddlt = finegrafptr->comploaddlt;
@@ -135,7 +135,7 @@ const KgraphMapMlParam * const        paraptr)    /*+ Method parameters
       kgraphExit (coargrafptr);
       return (1);
     }
-    coargrafptr->r.m.flagval = MAPPINGFREEPART;   /* Free group leader                    */
+    coargrafptr->r.m.flagval = MAPPINGINCOMPLETE | MAPPINGFREEPART; /* Free group leader  */
     coargrafptr->r.m.parttax = coarparotab - coargrafptr->s.baseval; /* Set coarse arrays */
     coargrafptr->r.vmlotax   = coarvmlotab - coargrafptr->s.baseval;
 
@@ -243,25 +243,15 @@ const GraphCoarsenMulti * const coarmulttab)      /*+ Pointer to multinode array
 
   if (coargrafptr == NULL) {                      /* If no coarse graph provided             */
     if (mapAlloc (&finegrafptr->m) != 0) {        /* Allocate mapping arrays at lowest level */
-      errorPrint ("kgraphMapMlUncoarsen: cannot allocate mapping arrays");
+      errorPrint ("kgraphMapMlUncoarsen: cannot allocate mapping arrays (1)");
       return (1);
     }
     kgraphFrst (finegrafptr);                     /* Assign all vertices to first subdomain */
     return (0);
   }
 
-  if (((finegrafptr->m.flagval & MAPPINGFREEDOMN) != 0) && /* If fine domain array already allocated, free it */
-      (finegrafptr->m.domntab != NULL)) {
-    memFree (finegrafptr->m.domntab);
-    finegrafptr->m.flagval &= ~MAPPINGFREEDOMN;
-  }
-  finegrafptr->m.flagval |= (coargrafptr->m.flagval & MAPPINGFREEDOMN); /* Re-use coarse domain array in fine graph */
-  finegrafptr->m.domntab  = coargrafptr->m.domntab;
-  finegrafptr->m.domnnbr  = coargrafptr->m.domnnbr;
-  finegrafptr->m.domnmax  = coargrafptr->m.domnmax;
-  coargrafptr->m.domntab  = NULL;                 /* No need to free coarse graph domain array as it has been transferred */
-  if (mapAlloc (&finegrafptr->m) != 0) {          /* Allocate partition array if needed                                   */
-    errorPrint ("kgraphMapMlUncoarsen: cannot allocate mapping arrays");
+  if (mapAlloc (&finegrafptr->m) != 0) {          /* Allocate partition array if needed */
+    errorPrint ("kgraphMapMlUncoarsen: cannot allocate mapping arrays (2)");
     return (1);
   }
 
@@ -370,7 +360,19 @@ const KgraphMapMlParam * const    paraptr)        /*+ Method parameters +*/
   int                 o;
 
   if (kgraphMapMlCoarsen (grafptr, &coargrafdat, &coarmulttab, paraptr) == 0) {
-    if (((o = kgraphMapMl2         (&coargrafdat, paraptr))              == 0) &&
+    coargrafdat.m.flagval |= MAPPINGFREEDOMN;     /* Transfer ownership of mapping domain array to coarse graph */
+    coargrafdat.m.domntab  = grafptr->m.domntab;
+    grafptr->m.domntab     = NULL;
+
+    o = kgraphMapMl2 (&coargrafdat, paraptr);     /* Compute mapping on coarsened graph */
+
+    grafptr->m.flagval    = coargrafdat.m.flagval; /* Transfer (back) mapping domain array to fine graph */
+    grafptr->m.domntab    = coargrafdat.m.domntab;
+    grafptr->m.domnnbr    = coargrafdat.m.domnnbr;
+    grafptr->m.domnmax    = coargrafdat.m.domnmax;
+    coargrafdat.m.domntab = NULL;
+
+    if ((o == 0) &&                               /* If coarsened mapping succeeded */
         ((o = kgraphMapMlUncoarsen (grafptr, &coargrafdat, coarmulttab)) == 0) &&
         ((o = kgraphMapSt          (grafptr, paraptr->stratasc))         != 0)) /* Apply ascending strategy */
       errorPrint ("kgraphMapMl2: cannot apply ascending strategy");
