@@ -1,4 +1,4 @@
-/* Copyright 2007,2012,2018,2019,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2012,2018,2019,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 6.0  : from : 29 nov 2012     **/
 /**                                 to   : 25 apr 2018     **/
 /**                # Version 7.0  : from : 20 sep 2019     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 23 apr 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -102,13 +102,11 @@ Gnum * const                edloloctab)           /* Local edge load array (if a
 #ifdef SCOTCH_DEBUG_LIBRARY1
   if (sizeof (SCOTCH_Dgraph) < sizeof (Dgraph)) {
     errorPrint (STRINGIFY (SCOTCH_dgraphBuild) ": internal error");
-    return     (1);
+    return (1);
   }
+  if ((baseval < 0) || (baseval > 1))
+    errorPrintW (STRINGIFY (SCOTCH_dgraphBuild) ": non-standard base parameter");
 #endif /* SCOTCH_DEBUG_LIBRARY1 */
-  if ((baseval < 0) || (baseval > 1)) {
-    errorPrint (STRINGIFY (SCOTCH_dgraphBuild) ": invalid base parameter");
-    return     (1);
-  }
 
   srcgrafptr = (Dgraph *) CONTEXTOBJECT (grafptr); /* Use structure as source graph */
 
