@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2010,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,7 +52,7 @@
 /**                # Version 6.1  : from : 15 mar 2021     **/
 /**                                 to   : 15 mar 2021     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -265,12 +265,12 @@ SCOTCH_Idx * const          edloidx),         \
 
   SCOTCH_graphData (grafptr, baseptr, vertptr, &verttab, &vendtab, &velotab, &vlbltab,
                     edgeptr, &edgetab, &edlotab);
-  *vertidx = (verttab - indxptr) + 1;             /* Add 1 since Fortran indices start at 1 */
-  *vendidx = (vendtab - indxptr) + 1;
-  *veloidx = (velotab != NULL) ? (velotab - indxptr) + 1 : *vertidx;
-  *vlblidx = (vlbltab != NULL) ? (vlbltab - indxptr) + 1 : *vertidx;
-  *edgeidx = (edgetab - indxptr) + 1;
-  *edloidx = (edlotab != NULL) ? (edlotab - indxptr) + 1 : *edgeidx;
+  *vertidx = (SCOTCH_Idx) (verttab - indxptr) + 1; /* Add 1 since Fortran indices start at 1 */
+  *vendidx = (SCOTCH_Idx) (vendtab - indxptr) + 1;
+  *veloidx = (velotab != NULL) ? (SCOTCH_Idx) (velotab - indxptr) + 1 : *vertidx;
+  *vlblidx = (vlbltab != NULL) ? (SCOTCH_Idx) (vlbltab - indxptr) + 1 : *vertidx;
+  *edgeidx = (SCOTCH_Idx) (edgetab - indxptr) + 1;
+  *edloidx = (edlotab != NULL) ? (SCOTCH_Idx) (edlotab - indxptr) + 1 : *edgeidx;
 }
 
 /*
