@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2012-2014,2018,2019,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2012-2014,2018,2019,2023-2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,7 +52,7 @@
 /**                # Version 6.0  : from : 08 jan 2012     **/
 /**                                 to   : 29 sep 2019     **/
 /**                # Version 7.0  : from : 07 may 2019     **/
-/**                                 to   : 10 aug 2023     **/
+/**                                 to   : 29 sep 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -276,33 +276,30 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
 
   if (listnbr == 0) {                             /* If empty list, return identity permutation */
     intAscn (libordeptr->o.peritab, srcgrafptr->vertnbr, srcgrafptr->baseval);
-    goto abort;
+    o = 0;                                        /* Not an error */
+    goto skip;
   }
 
   if (*((Strat **) stratptr) == NULL)             /* Set default ordering strategy if necessary */
     SCOTCH_stratGraphOrderBuild (stratptr, SCOTCH_STRATQUALITY, 0, 0.2);
 
   ordstratptr = *((Strat **) stratptr);
-  if (ordstratptr->tabl != &hgraphorderststratab) {
+  if (ordstratptr->tablptr != &hgraphorderststratab) {
     errorPrint (STRINGIFY (SCOTCH_graphOrderComputeList) ": not an ordering strategy");
     goto abort;
   }
 
-  memCpy (&halgrafdat.s, srcgrafptr, sizeof (Graph)); /* Copy non-halo graph data */
-  halgrafdat.s.flagval &= ~GRAPHFREETABS;         /* Do not allow to free arrays  */
-  halgrafdat.s.edlotax  = NULL;                   /* Don't mind about edge loads  */
-  halgrafdat.vnohnbr    = halgrafdat.s.vertnbr;   /* All vertices are non-halo    */
-  halgrafdat.vnohnnd    = halgrafdat.s.vertnnd;   /* No halo present              */
-  halgrafdat.vnhdtax    = halgrafdat.s.vendtax;   /* End of non-halo vertices     */
-  halgrafdat.vnlosum    = halgrafdat.s.velosum;   /* Sum of node vertex weights   */
-  halgrafdat.enohnbr    = halgrafdat.s.edgenbr;   /* No halo present              */
-  halgrafdat.enlosum    = halgrafdat.s.edlosum;
-  halgrafdat.levlnum    = 0;                      /* No nested dissection yet */
-  halgrafdat.contptr    = CONTEXTGETDATA (libgrafptr);
+  memCpy (&halgrafdat.s, srcgrafptr, sizeof (Graph)); /* Copy non-halo graph data   */
+  halgrafdat.s.flagval &= ~GRAPHFREETABS;         /* Do not allow to free arrays    */
+  halgrafdat.s.edlotax  = NULL;                   /* Never mind about edge loads    */
+  halgrafdat.s.vlbltax  = NULL;                   /* Do not propagate vertex labels */
+  hgraphUnhalo2 (&halgrafdat);                    /* Set default halo members       */
+  halgrafdat.levlnum = 0;                         /* No nested dissection yet       */
+  halgrafdat.contptr = CONTEXTGETDATA (libgrafptr);
 
   if (listnbr == srcgrafptr->vertnbr) {           /* If work on full graph */
     halgrafptr = &halgrafdat;
-    cblkptr    = &libordeptr->o.cblktre;
+    cblkptr    = &libordeptr->o.rootdat;
   }
   else {
     Gnum * restrict       peritax;
@@ -316,10 +313,10 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
     }
     libordeptr->o.treenbr = 3;
     libordeptr->o.cblknbr = 2;
-    libordeptr->o.cblktre.typeval = ORDERCBLKDICO; /* Node is a set of two disconnected components */
-    libordeptr->o.cblktre.vnodnbr = srcgrafptr->vertnbr;
-    libordeptr->o.cblktre.cblknbr = 2;
-    libordeptr->o.cblktre.cblktab = cblkptr;
+    libordeptr->o.rootdat.typeval = ORDERCBLKDICO; /* Node is a set of two disconnected components */
+    libordeptr->o.rootdat.vnodnbr = srcgrafptr->vertnbr;
+    libordeptr->o.rootdat.cblknbr = 2;
+    libordeptr->o.rootdat.cblktab = cblkptr;
 
     cblkptr[0].typeval = ORDERCBLKLEAF;           /* Build column blocks */
     cblkptr[0].vnodnbr = listnbr;
@@ -368,9 +365,12 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
   if (o != 0)
     goto abort;
 
+skip:
 #ifdef SCOTCH_DEBUG_LIBRARY2
-  if (orderCheck (&libordeptr->o) != 0)
+  if (orderCheck (&libordeptr->o) != 0) {
+    o = 1;
     goto abort;
+  }
 #endif /* SCOTCH_DEBUG_LIBRARY2 */
 
   if (libordeptr->permtab != NULL)                /* Build direct permutation if wanted */
