@@ -58,7 +58,7 @@
 /**                # Version 6.1  : from : 15 mar 2021     **/
 /**                                 to   : 15 mar 2021     **/
 /**                # Version 7.0  : from : 27 aug 2019     **/
-/**                                 to   : 09 jan 2025     **/
+/**                                 to   : 14 aug 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -125,6 +125,10 @@ typedef struct {
   double                    dummy[DUMMYSIZEDMAP];
 } SCOTCH_Dmapping;
 
+typedef struct {
+  double                    dummy[DUMMYSIZEDMESH];
+} SCOTCH_Dmesh;
+
 typedef struct {
   double                    dummy[DUMMYSIZEDORDER];
 } SCOTCH_Dordering;
@@ -193,6 +197,17 @@ int                         SCOTCH_dgraphOrderGather (const SCOTCH_Dgraph * cons
 SCOTCH_Dmapping *           SCOTCH_dmapAlloc    (void);
 int                         SCOTCH_dmapSizeof   (void);
 
+SCOTCH_Dmesh *              SCOTCH_dmeshAlloc   (void);
+int                         SCOTCH_dmeshSizeof  (void);
+int                         SCOTCH_dmeshInit    (SCOTCH_Dmesh * const, MPI_Comm);
+void                        SCOTCH_dmeshExit    (SCOTCH_Dmesh * const);
+void                        SCOTCH_dmeshFree    (SCOTCH_Dmesh * const);
+void                        SCOTCH_dmeshSize    (const SCOTCH_Dmesh * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const);
+void                        SCOTCH_dmeshData    (const SCOTCH_Dmesh * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num ** const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num ** const, SCOTCH_Num * const, MPI_Comm * const);
+int                         SCOTCH_dmeshBuildAdm (SCOTCH_Dmesh * const, const SCOTCH_Num, const SCOTCH_Num, SCOTCH_Num * const, const SCOTCH_Num, SCOTCH_Num * const, const SCOTCH_Num);
+int                         SCOTCH_dmeshDgraphDual (const SCOTCH_Dmesh * const, SCOTCH_Dgraph * const, const SCOTCH_Num);
+int                         SCOTCH_dmeshLoad    (SCOTCH_Dmesh * const, FILE * const, const SCOTCH_Num, const SCOTCH_Num);
+
 SCOTCH_Dordering *          SCOTCH_dorderAlloc  (void);
 int                         SCOTCH_dorderSizeof (void);
 
