@@ -55,7 +55,7 @@
 /**                # Version 6.1  : from : 24 aug 2020     **/
 /**                                 to   : 30 dec 2021     **/
 /**                # Version 7.0  : from : 19 feb 2018     **/
-/**                                 to   : 29 aug 2025     **/
+/**                                 to   : 12 sep 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -723,6 +723,7 @@
 #define bgraphBipartDfJoin          SCOTCH_NAME_INTERN (bgraphBipartDfJoin)
 #define bgraphBipartEx              SCOTCH_NAME_INTERN (bgraphBipartEx)
 #define bgraphBipartFm              SCOTCH_NAME_INTERN (bgraphBipartFm)
+#define bgraphBipartGa              SCOTCH_NAME_INTERN (bgraphBipartGa)
 #define bgraphBipartGg              SCOTCH_NAME_INTERN (bgraphBipartGg)
 #define bgraphBipartGp              SCOTCH_NAME_INTERN (bgraphBipartGp)
 #define bgraphBipartMl              SCOTCH_NAME_INTERN (bgraphBipartMl)
@@ -899,6 +900,7 @@
 #define hdgraphOrderNd              SCOTCH_NAME_INTERN (hdgraphOrderNd)
 #define hdgraphOrderNd2             SCOTCH_NAME_INTERN (hdgraphOrderNd2)
 #define hdgraphOrderSi              SCOTCH_NAME_INTERN (hdgraphOrderSi)
+#define hdgraphOrderSi2             SCOTCH_NAME_INTERN (hdgraphOrderSi2)
 #define hdgraphOrderSq              SCOTCH_NAME_INTERN (hdgraphOrderSq)
 #define hdgraphOrderSq2             SCOTCH_NAME_INTERN (hdgraphOrderSq2)
 #define hdgraphOrderSt              SCOTCH_NAME_INTERN (hdgraphOrderSt)
@@ -922,6 +924,7 @@
 #define hgraphOrderSi               SCOTCH_NAME_INTERN (hgraphOrderSi)
 #define hgraphOrderSt               SCOTCH_NAME_INTERN (hgraphOrderSt)
 #define hgraphUnhalo                SCOTCH_NAME_INTERN (hgraphUnhalo)
+#define hgraphUnhalo2               SCOTCH_NAME_INTERN (hgraphUnhalo2)
 
 #define hmeshorderststratab         SCOTCH_NAME_INTERN (hmeshorderststratab)
 #define hmeshExit                   SCOTCH_NAME_INTERN (hmeshExit)
@@ -1016,7 +1019,7 @@
 #define meshGeomLoadHabo            SCOTCH_NAME_INTERN (meshGeomLoadHabo)
 #define meshGeomLoadScot            SCOTCH_NAME_INTERN (meshGeomLoadScot)
 #define meshGeomSaveScot            SCOTCH_NAME_INTERN (meshGeomSaveScot)
-#define meshGraph                   SCOTCH_NAME_INTERN (meshGraph)
+#define meshGraphNodal              SCOTCH_NAME_INTERN (meshGraphNodal)
 #define meshGraphDual               SCOTCH_NAME_INTERN (meshGraphDual)
 #define meshInduceList              SCOTCH_NAME_INTERN (meshInduceList)
 #define meshInducePart              SCOTCH_NAME_INTERN (meshInducePart)
