@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2018,2021 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2018,2019,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,7 +34,7 @@
 /**   NAME       : vgraph_separate_bd.c                    **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
-/**                Cedric CHEVALIER                        **/
+/**                Cedric CHEVALIER (v5.0)                 **/
 /**                                                        **/
 /**   FUNCTION   : This module builds a band graph around  **/
 /**                the frontier in order to decrease       **/
@@ -49,6 +49,8 @@
 /**                                 to   : 31 may 2018     **/
 /**                # Version 6.1  : from : 02 nov 2021     **/
 /**                                 to   : 21 nov 2021     **/
+/**                # Version 7.0  : from : 05 may 2019     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -56,8 +58,6 @@
 **  The defines and includes.
 */
 
-#define VGRAPH_SEPARATE_BD
-
 #include "module.h"
 #include "common.h"
 #include "parser.h"
@@ -199,7 +199,7 @@ const VgraphSeparateBdParam * const paraptr)      /*+ Method parameters +*/
     }
   } while (! vgraphSeparateBdQueueEmpty (&queudat)); /* As long as queue is not empty */
 
-  bndvertnbr = queudat.head - queudat.qtab;       /* Number of regular band graph vertices (withour anchors) is number of enqueued vertices */
+  bndvertnbr = (Gnum) (queudat.head - queudat.qtab); /* Number of regular band graph vertices (withour anchors) is number of enqueued vertices */
 
   if (orgvelotax == NULL) {
     bndvelosum   = bndvertnbr;
@@ -385,6 +385,7 @@ const VgraphSeparateBdParam * const paraptr)      /*+ Method parameters +*/
   bndgrafdat.dwgttab[0]  = orggrafptr->dwgttab[0]; /* Preserve respective weights */
   bndgrafdat.dwgttab[1]  = orggrafptr->dwgttab[1];
   bndgrafdat.levlnum     = orggrafptr->levlnum;
+  bndgrafdat.contptr     = orggrafptr->contptr;
 
 #ifdef SCOTCH_DEBUG_VGRAPH2
   if ((graphCheck (&bndgrafdat.s) != 0) ||        /* Check band graph consistency */
