@@ -719,8 +719,8 @@ GainLink * const                    lockptr)
   Gnum                              hashsiz;
   Gnum                              hashmax;
   Gnum                              hashmsk;
-  Gnum                              hashsta;      /* Start index of range of hash indices to move */
-  Gnum                              hashend;      /* End index of range of hash indices to move   */
+  Gnum                              hashbas;      /* Start index of range of hash indices to move */
+  Gnum                              hashnnd;      /* End index of range of hash indices to move   */
   Gnum                              hashnum;
 
   hashmax = *hashmaxptr << 1;                     /* Compute new sizes */
@@ -754,10 +754,11 @@ GainLink * const                    lockptr)
   lockptr->next =                                 /* Rebuild lock list */
   lockptr->prev = lockptr;
 
-  for (hashsta = hashold - 1; hashtab[hashsta].vertnum != ~0; hashsta --) ; /* Start index of first segment to reconsider is last empty slot */
-  hashend = hashold;                              /* First segment to reconsider ends at the end of the old array                            */
-  while (hashend != hashsta) {                    /* For each of the two segments to consider                                                */
-    for (hashnum = hashsta; hashnum < hashend; hashnum ++) { /* Re-compute position of vertices in new table                                 */
+  for (hashbas = hashold - 1; hashtab[hashbas].vertnum != ~0; hashbas --) ; /* Find start index of last block     */
+  hashnnd = hashold;                              /* First segment to reconsider ends at the end of the old array */
+
+  while (hashnnd != hashbas) {                    /* For each of the two segments to consider                */
+    for (hashnum = hashbas; hashnum < hashnnd; hashnum ++) { /* Re-compute position of vertices in new table */
       Gnum                        vertnum;
 
       vertnum = hashtab[hashnum].vertnum;
@@ -769,7 +770,7 @@ GainLink * const                    lockptr)
             break;                                /* There is nothing to do   */
           if (hashtab[hashnew].vertnum == ~0) {   /* If new slot is empty     */
 #ifdef SCOTCH_DEBUG_VGRAPH2
-            if ((hashnew > hashnum) && (hashnew < hashend)) { /* If vertex is not moved either before its old position or after the end of the segment */
+            if ((hashnew > hashnum) && (hashnew < hashnnd)) { /* If vertex is not moved either before its old position or after the end of the segment */
               errorPrint ("vgraphSeparateFmResize: internal error (1)");
               return (1);
             }
@@ -794,9 +795,9 @@ GainLink * const                    lockptr)
       }
     }
 
-    hashend = hashsta;                            /* End of second segment to consider is start of first one    */
-    hashsta = 0;                                  /* Start of second segment is beginning of array              */
-  }                                               /* After second segment, hashsta = hashend = 0 and loop stops */
+    hashnnd = hashbas;                            /* End of second segment to consider is start of first one    */
+    hashbas = 0;                                  /* Start of second segment is beginning of array              */
+  }                                               /* After second segment, hashbas = hashnnd = 0 and loop stops */
 
   for (savenum = 0; savenum < savenbr; savenum ++) {
     Gnum                  vertnum;
