@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2023 Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019,2023,2024 Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -62,7 +62,7 @@
 /**                # Version 6.0  : from : 01 jan 2012     **/
 /**                                 to   : 24 sep 2019     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 10 sep 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -81,7 +81,7 @@
 
 static int                  C_inpFormatType  = 0; /* Input graph format           */
 static char *               C_inpFormatData  = "\0"; /* Pointer to auxiliary data */
-static const C_Format       C_inpFormatTab[] = {  /* Table of input formats       */
+static const C_FormatInp    C_inpFormatTab[] = {  /* Table of input formats       */
                               { 'B',  SCOTCH_graphGeomLoadHabo },
                               { 'b',  SCOTCH_graphGeomLoadHabo },
                               { 'C',  SCOTCH_graphGeomLoadChac },
@@ -94,7 +94,7 @@ static const C_Format       C_inpFormatTab[] = {  /* Table of input formats
 
 static int                  C_outFormatType  = 4; /* Output graph format          */
 static char *               C_outFormatData  = "\0"; /* Pointer to auxiliary data */
-static C_Format             C_outFormatTab[] = {  /* Table of output formats      */
+static C_FormatOut          C_outFormatTab[] = {  /* Table of output formats      */
                               { 'C',  SCOTCH_graphGeomSaveChac },
                               { 'c',  SCOTCH_graphGeomSaveChac },
                               { 'M',  SCOTCH_graphGeomSaveMmkt },
